# John and Kitty
# 24.11.2021
# Boxplots
# and heatmap of relative abundance

# load libraries
library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(pheatmap)
library(RColorBrewer)
library(scales)

# create necessary functions
calculate_relative_abundance <- function(x) x / sum(x)

calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

# set seed
set.seed(711)

# import data
biom_file <- import_biom("table-with-taxonomy.biom")
metadata  <- import_qiime_sample_data("sample-metadata.tsv")
tree      <- read_tree_greengenes("tree.nwk")

tree <- multi2di(tree)

# create physeq object
physeq <- merge_phyloseq(biom_file, metadata, tree)

# add labels for taxonomic levels
colnames(tax_table(physeq)) <- c("Kingdom", "Phylum", "Class","Order", "Family",
                                 "Genus", "Species")

# creating relative abundance plot of g_Staphylococcus

# subset the physeq object to just samples from the "building" biome
building <- subset_samples(physeq, env_feature == "building")

# calculate relative abundance
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# 
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")

# plot_genus <- function (Bug) {
#   BugName <-  deparse(substitute(Bug))
#   g__BugName <- paste("g__", BugName, sep = "")
#   g__BugName
Bug <- subset_taxa(abundant_building_RA_genera, Genus == "g__Brevundimonas")
  
otu_table(Bug)



#transform the data fram from wide to long format
Bug_long <- psmelt(Bug)
Bug_long

#re-ordering and re-labelling categories
Bug_long$orig_env_material <- factor(Bug_long$orig_env_material, 
                                                levels=c(
                                                  "plastic", "wood"), 
                                                labels=c("Plastic", "Wood"))

#adding percentages 

# Bug_long %>% 
#   count(day) %>% 
#   mutate(perc = n / nrow(tips)) -> tips2
# #creating ggplot

p <- ggplot(Bug_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  scale_y_continuous(labels=scales::percent) +
  labs(
    x     = "Surface Type",
    y     = "Relative Abundance",
  )

p <- p + labs(fill = "Original 
Environmental 
Material")

p <- p + theme_bw()

p <- p + theme(panel.grid.major = element_blank(), 
               panel.grid.minor = element_blank(), 
               text=element_text(size = 16))

p







